# Instructions 

#### This is our test project. 
#### Please install this package 
```
pip install functions-by-elikanzharbek
```

#### You can also install older  package 
```
pip install functions-by-elikanzharbek==VERSION_NUMBER
```
